@@ -9,6 +9,7 @@ import pkg_resources  # part of setuptools
 version = pkg_resources.require("bridge-utils")[0].version
 
 from .pbn_parser import importPBN, ParseError
+#from pbn_parser import importPBN, ParseError
 
 from string import Template
 
@@ -23,8 +24,8 @@ html_template="""
     <title>Enjoy the bridge game</title>
   </head>
   <h2>Introduction</h2>
-  <p>this is designed to be used (copy/paste) for Microsoft Word (Chinese) directly</p>
-  <p>Designed by Larry Cai and produced by <a href="https://pypi.org/project/pbn2html/">pbn2html</a>, version $version</p>
+  <p>this is designed to be used (copy/paste) for HTML/Microsoft Word</p>
+  <p>Designed by Larry Cai and produced by <a href="https://pypi.org/project/bridge-utils/">bridge-utils/pbn2html</a>, version $version</p>
   <p>Credit to <a href="https://bridgecomposer.com/">BridgeComposer Version 5.83 (64 bit)</a></p>
   <body class=bcbody>
     <!-- Credit to BridgeComposer Version 5.83 (64 bit) - https://bridgecomposer.com/ -->
@@ -80,7 +81,9 @@ board_template="""
               </table>
 """
 extra_template="""
-            <td class=bchd3 style="padding: 1px; font: 10pt Verdana, sans-serif; padding: 1px; text-align: left; vertical-align: top;">$contract<br />by $declarer</td>
+            <td class=bchd3 style="padding: 1px; font: 10pt Verdana, sans-serif; padding: 1px; text-align: left; vertical-align: top;">
+                $contract by $declarer<br />Lead: $lead
+            </td>
 """
 
 info_template="""
@@ -165,13 +168,19 @@ def contract_css(contract):
 
     return css
 
-def html_extra(contract, declarer):
+def html_extra(contract, declarer,lead):
     src = Template(extra_template)
     css = contract_css(contract)
     # trans_declarer={"S": "南","W": "西","N": "北","E": "东"}
     # trans_declarer={"S": "S","W": "W","N": "N","E": "E"}
+    suit_css = {
+        'S':  "<span class=bcspades style='color:black;font: 10pt Verdana, sans-serif;'>&spades;</span>",
+        "H":  "<span class=bchearts style='color: red; font: 10pt Verdana, sans-serif;'>&hearts;</span>",
+        "D":  "<span class=bcdiams style='color: red; font: 10pt Verdana, sans-serif;'>&diams;</span>",
+        "C":  "<span class=bcclubs style='color:black;font: 10pt Verdana, sans-serif;'>&clubs;</span>"
+    }
     trans_declarer={"S": "South","W": "West","N": "North","E": "East"}
-    all = { "declarer": trans_declarer[declarer], "contract" : css}
+    all = { "declarer": trans_declarer[declarer], "contract" : css, "lead" : suit_css[lead[0]] + lead[1]}
     return src.safe_substitute(all)
 
 def html_info(info, bottom=False):
@@ -232,26 +241,31 @@ def pbn2html(pbn_file):
         # print("==================================", pbn)
         try:
             tags, hands, section_auction = importPBN(pbn)
-            # bug from Jay
-            if "Event" not in tags:
-                tags["Event"] = ""
-            # print(tags, hands,section_auction)
+            #print(tags, hands,section_auction)
             all["title"] = tags["Event"]
             all["north"] = html_card(hands["N"])
             all["west"] = html_card(hands["W"])
             all["east"] = html_card(hands["E"])
             all["south"] = html_card(hands["S"])
             all["board"] = html_board(tags["Vulnerable"],tags["Dealer"])
-            all["extra"] = html_extra(tags["Contract"],tags["Declarer"])
+            all["extra"] = html_extra(tags["Contract"],tags["Declarer"],tags["Lead"])
             all["auction"] = html_auction(tags["Auction"], section_auction)
             # hacked solution to check whether it is module or local
-            # > _: C:/Python36/Scripts/pbn2html
-            if "pbn2html" in os.environ.get("_"):
-                template = pkgutil.get_data(__name__,'template.html')
-                src = Template(template.decode('utf-8'))
-            else:
+            # windows module
+            # _: C:/Users/rdccaiy/AppData/Local/Programs/Python/Python38/Scripts/pbn2html
+            # unix module
+            # _: /home/rdccaiy/py3env/bin/pbn2html
+            # local (python3.8)
+            # _: ./pbn2html.py
+            #for item, value in os.environ.items():
+            #    print('{}: {}'.format(item, value))
+            if "pbn2html.py" in os.environ.get("_"):
                 template = open("template.html", "r",encoding="utf-8").read()
                 src = Template(template)
+            else:
+                template = pkgutil.get_data(__name__,'template.html')
+                src = Template(template.decode('utf-8'))
+
             result += src.safe_substitute(all)
         except ParseError as error:
             print(error)
